;; Generated package description from ellama.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "ellama" "1.9.1" "Tool for interacting with LLMs" '((emacs "28.1") (llm "0.24.0") (plz "0.8") (transient "0.7") (compat "29.1")) :commit "dfda86230dd312ad259eb4b7b1264546f0a02810" :authors '(("Sergey Kostyaev" . "sskostyaev@gmail.com")) :maintainer '("Sergey Kostyaev" . "sskostyaev@gmail.com") :keywords '("help" "local" "tools") :url "http://github.com/s-kostyaev/ellama")
